@@ -5,7 +5,6 @@ use futures::{
     stream::{Stream, StreamExt},
     Future, FutureExt,
 };
-use lazy_static::lazy_static;
 use std::{
     collections::HashMap,
     convert::TryFrom,
@@ -15,7 +14,7 @@ use std::{
     mem::size_of,
     pin::Pin,
     sync::{
-        atomic::{AtomicBool, AtomicU16, Ordering},
+        atomic::{AtomicBool, Ordering},
         Arc,
     },
     task::{Context, Poll},
@@ -201,8 +200,6 @@ impl TransportMsg {
 /// Channel multiplexer.
 #[must_use = "You must call run() on the ChMux object for the connection to work."]
 pub struct ChMux<TransportSink, TransportStream> {
-    /// Trace id.
-    trace_id: String,
     /// Our configuration.
     local_cfg: Cfg,
     /// Remote configuration.
@@ -244,7 +241,6 @@ pub struct ChMux<TransportSink, TransportStream> {
 impl<TransportSink, TransportStream> fmt::Debug for ChMux<TransportSink, TransportStream> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("ChMux")
-            .field("trace_id", &self.trace_id)
             .field("local_cfg", &self.local_cfg)
             .field("remote_cfg", &self.remote_cfg)
             .field("local_protocol_version", &PROTOCOL_VERSION)
@@ -267,20 +263,13 @@ where
     ///
     /// # Panics
     /// Panics if specified configuration does not obey limits documented in [Cfg].
-    #[tracing::instrument(level = "debug", skip_all, fields(chmux))]
+    #[tracing::instrument(level = "trace", skip_all, fields(cfg))]
     pub async fn new(
         cfg: Cfg, mut transport_sink: TransportSink, mut transport_stream: TransportStream,
     ) -> Result<(Self, Client, Listener), ChMuxError<TransportSinkError, TransportStreamError>> {
         // Check configuration.
         cfg.check();
 
-        // Get trace id.
-        let trace_id = match cfg.trace_id.clone() {
-            Some(trace_id) => trace_id,
-            None => generate_trace_id(),
-        };
-        tracing::Span::current().record("chmux", &trace_id.as_str());
-
         // Say hello to remote endpoint and exchange configurations.
         let fut = Self::exchange_hello(&cfg, &mut transport_sink, &mut transport_stream);
         let (remote_protocol_version, remote_cfg) = match cfg.connection_timeout {
@@ -299,7 +288,6 @@ where
         let port_allocator = PortAllocator::new(cfg.max_ports);
         let remote_listener_dropped = Arc::new(AtomicBool::new(false));
         let multiplexer = ChMux {
-            trace_id,
             remote_protocol_version,
             local_cfg: cfg,
             remote_cfg: remote_cfg.clone(),
@@ -333,7 +321,7 @@ where
     }
 
     /// Feed transport message to sink and log it.
-    #[tracing::instrument(level="trace", skip_all, fields(msg=?msg.msg, data=?msg.data))]
+    #[tracing::instrument(level = "trace", skip_all, fields(msg=?msg.msg, data=?msg.data))]
     async fn feed_msg(
         msg: TransportMsg, sink: &mut TransportSink,
     ) -> Result<(), ChMuxError<TransportSinkError, TransportStreamError>> {
@@ -384,7 +372,7 @@ where
     }
 
     /// Exchange Hello message with remote endpoint.
-    #[tracing::instrument(level = "debug", skip_all)]
+    #[tracing::instrument(level = "trace", skip_all)]
     async fn exchange_hello(
         cfg: &Cfg, sink: &mut TransportSink, stream: &mut TransportStream,
     ) -> Result<(u8, ExchangedCfg), ChMuxError<TransportSinkError, TransportStreamError>> {
@@ -437,14 +425,14 @@ where
         terminate |= self.goodbye_received;
 
         if terminate {
-            tracing::debug!("should terminate");
+            tracing::trace!("should terminate");
         }
 
         terminate
     }
 
     /// Create port in port registry and return associated sender and receiver.
-    #[tracing::instrument(level = "debug")]
+    #[tracing::instrument(level = "trace")]
     fn create_port(&mut self, local_port: PortNumber, remote_port: u32) -> (Sender, Receiver) {
         let local_port_num = *local_port;
 
@@ -538,7 +526,7 @@ where
         }
 
         if free {
-            tracing::debug!(local_port, "freed port");
+            tracing::trace!(local_port, "freed port");
             self.ports.remove(&local_port);
         }
     }
@@ -635,7 +623,7 @@ where
     ///
     /// The dispatcher terminates when the client, server and all channels have been dropped or
     /// the transport is closed.
-    #[tracing::instrument(level = "debug", skip_all, fields(chmux=self.trace_id.as_str()))]
+    #[tracing::instrument(level = "trace", skip_all)]
     pub async fn run(mut self) -> Result<(), ChMuxError<TransportSinkError, TransportStreamError>> {
         let mut transport_sink = self.transport_sink.take().unwrap();
         let mut transport_stream = self.transport_stream.take().unwrap();
@@ -740,12 +728,12 @@ where
     }
 
     /// Handle local event that results in sending a message to the remote endpoint.
-    #[tracing::instrument(level = "debug", skip_all, fields(event=?event))]
+    #[tracing::instrument(level = "trace", skip_all, fields(event=?event))]
     async fn handle_event(
         &mut self, permit: Permit<'_, SendCmd>, event: GlobalEvt,
     ) -> Result<(), ChMuxError<TransportSinkError, TransportStreamError>> {
         let send_msg = |permit: Permit<'_, SendCmd>, msg: MultiplexMsg| {
-            tracing::debug!(op="send", msg=?msg);
+            tracing::trace!(op="send", msg=?msg);
             permit.send(SendCmd::Send(TransportMsg::new(msg)))
         };
 
@@ -782,7 +770,7 @@ where
             // Send data from port.
             GlobalEvt::Port(PortEvt::SendData { remote_port, data, first, last }) => {
                 let msg = MultiplexMsg::Data { port: remote_port, first, last };
-                tracing::debug!(op="send", msg=?msg, data=?&data);
+                tracing::trace!(op="send", msg=?msg, data=?&data);
                 permit.send(SendCmd::Send(TransportMsg::with_data(msg, data)));
             }
 
@@ -884,7 +872,7 @@ where
     }
 
     /// Handle message received from remote endpoint.
-    #[tracing::instrument(level = "debug", skip_all, fields(msg=?received_msg.msg, data=?received_msg.data))]
+    #[tracing::instrument(level = "trace", skip_all, fields(msg=?received_msg.msg, data=?received_msg.data))]
     async fn handle_received_msg(
         &mut self, received_msg: TransportMsg,
     ) -> Result<(), ChMuxError<TransportSinkError, TransportStreamError>> {
@@ -1195,13 +1183,3 @@ where
         Pin::into_inner(self).sink.poll_ready_unpin(cx)
     }
 }
-
-/// Generate trace id.
-fn generate_trace_id() -> String {
-    lazy_static! {
-        static ref ID: AtomicU16 = AtomicU16::new(0);
-    }
-
-    let id = ID.fetch_add(1, Ordering::SeqCst);
-    format!("{:04x}", id)
-}
